﻿using System.Web;
using System.Web.Mvc;
using System.Web.Routing;
using GPAS.Models.Interfaces;
using GPAS.Models.Services;
using GPAS.Utility;
using Microsoft.Practices.Unity;

namespace GPAS
{
    public class MvcApplication : HttpApplication
    {
        public static void RegisterGlobalFilters(GlobalFilterCollection filters)
        {
            filters.Add(new HandleErrorAttribute());
        }

        public static void RegisterRoutes(RouteCollection routes)
        {
            routes.IgnoreRoute("{resource}.axd/{*pathInfo}");

            // Se definen las rutas de la aplicación
            routes.MapRoute(
                "Default", // Nombre de ruta
                "{controller}/{action}/{id}", // URL con parámetros
                new {controller = "Inicio", action = "Indice", id = UrlParameter.Optional}
                // Valores predeterminados de parámetro
                );
        }

        protected void Application_Start()
        {
            AreaRegistration.RegisterAllAreas();

            // Se registran los filtros y las rutas de la aplicación
            RegisterGlobalFilters(GlobalFilters.Filters);
            RegisterRoutes(RouteTable.Routes);

            // Se inicializa y se registra el contenedor de inyección de dependencia de Unity
            IUnityContainer container = InitContainer();
            DependencyResolver.SetResolver(new UnityDependencyResolver(container));
        }

        /// <summary>
        /// Se inicializa el contenedor de inyección de dependencias de Unity proporcionando un sistema para gestionar 
        /// tanto la construcción de objetos como las dependencias entre los diferentes componentes de una aplicación.
        /// </summary>
        private IUnityContainer InitContainer()
        {
            var container = new UnityContainer();
            // Objetos de servicio de datos 
            // (solo se han incluido estos pero se podria añadir otros objetos de la aplicación para evitar el acoplamiento).
            container.RegisterType<IAccionService, AccionService>();
            container.RegisterType<IActividadService, ActividadService>();
            container.RegisterType<IContactoService, ContactoService>();
            container.RegisterType<IDelegacionService, DelegacionService>();
            container.RegisterType<IDocumentoService, DocumentoService>();
            container.RegisterType<IEntidadService, EntidadService>();
            container.RegisterType<IEstadoService, EstadoService>();
            container.RegisterType<IEventoService, EventoService>();
            container.RegisterType<IFotoService, FotoService>();
            container.RegisterType<IMedioService, MedioService>();
            container.RegisterType<IOrganizacionService, OrganizacionService>();
            container.RegisterType<IParticipacionService, ParticipacionService>();
            container.RegisterType<IPoblacionService, PoblacionService>();
            container.RegisterType<IProvinciaService, ProvinciaService>();
            container.RegisterType<IRolService, RolService>();
            container.RegisterType<ISeguimientoService, SeguimientoService>();
            container.RegisterType<ITematicaService, TematicaService>();
            container.RegisterType<ITipoEntidadService, TipoEntidadService>();
            container.RegisterType<ITipoOrganizacionService, TipoOrganizacionService>();
            container.RegisterType<ITipoParticipacionService, TipoParticipacionService>();
            container.RegisterType<IUsuarioService, UsuarioService>();

            return container;
        }
    }
}