﻿using System;
using System.Collections.Generic;

namespace GPAS.Models.Interfaces
{
    /// <summary>
    ///  Enumerador para definir la dirección del orden de la páginación
    /// </summary>
    public enum Orden
    {
        Ascendente,
        Descendente
    }

    /// <summary>
    ///  Interfaz base de servicio. Establece los metodos necesarios para implementar en los servicios.
    /// </summary>
    public interface IBaseService<TEntity, TEntityId>
        where TEntity : class
        where TEntityId : struct
    {
        bool Guardar(TEntity entity);
        bool Borrar(TEntityId id);
        int Contar();

        IEnumerable<TEntity> ObtenerFiltro(int pagina, int filas, string columnaOrdenacion, string sentidoOrdenacion,
                                           string textoBuscar);

        IEnumerable<TEntity> ObtenerTodos(int pagina, int filas, Func<TEntity, IComparable> funcOrden, Orden orden);
        IEnumerable<TEntity> ObtenerTodos();
        TEntity ObtenerId(TEntityId id);
    }
}