﻿using System.ComponentModel;
using System.ComponentModel.DataAnnotations;
using System.Web.Mvc;

namespace GPAS.Models
{
    /// <summary>   
    /// Se usa el atributo MetadataType para indicar en que clase se encuentran las anotaciones
    /// de la clase parcial Accion generada por el ORM (Entity Framework)
    /// </summary>
    [MetadataType(typeof (AccionMetadata))]
    public partial class Accion
    {
        /// <summary>   
        /// Propiedad que devuelve el nombre completo de la acción de una organización
        /// </summary>
        public string NombreCompleto
        {
            get
            {
                if (Organizacion != null)
                    return Organizacion.Nombre + " - " + Nombre;
                else
                    return Nombre;
            }
        }
    }

    /// <summary>
    /// Se crea una clase 'buddy' como contenedor de anotaciones de la clase Accion
    /// </summary>
    public class AccionMetadata
    {
        [DisplayName("Id. acción")]
        public int IdAccion { get; set; }

        [Required]
        [DisplayName("Organizacion")]
        public int IdOrganizacion { get; set; }

        [Required]
        [DisplayName("Temática")]
        public int IdTematica { get; set; }
        
        [Required]
        [DisplayName("Actividad")]
        public int IdActividad { get; set; }

        [Required(ErrorMessage = "El {0} es obligatorio")]
        [DisplayName("Nombre")]
        [StringLength(50, ErrorMessage = "Introduzca un máximo de {1} caracteres")]
        public string Nombre { get; set; }

        [DisplayName("Activo")]
        public bool Activo { get; set; }

        [AllowHtml]
        [DisplayName("Observaciones")]
        [StringLength(5000, ErrorMessage = "Introduzca un máximo de {1} caracteres")]
        [DataType(DataType.MultilineText)]
        public string Observaciones { get; set; }
    }
}