﻿using System.ComponentModel;
using System.ComponentModel.DataAnnotations;

namespace GPAS.Models
{
    /// <summary>   
    /// Se usa el atributo MetadataType para indicar en que clase se encuentran las anotaciones
    /// de la clase parcial Contacto generada por el ORM (Entity Framework)
    /// </summary>
    [MetadataType(typeof (ContactoMetadata))]
    public partial class Contacto
    {    
    }

    /// <summary>
    /// Se crea una clase 'buddy' como contenedor de anotaciones de la clase Contacto
    /// </summary>
    public class ContactoMetadata
    {
        [DisplayName("Id. contacto")]
        public int IdContacto { get; set; }

        [Required(ErrorMessage = "La {0} es obligatoria")]
        [DisplayName("Entidad")]
        public int IdEntidad { get; set; }

        [Required(ErrorMessage = "El {0} es obligatorio")]
        [DisplayName("Nombre")]
        [StringLength(50, ErrorMessage = "Introduzca un máximo de {1} caracteres")]
        public string Nombre { get; set; }

        [Required(ErrorMessage = "Los {0} son obligatorios")]
        [DisplayName("Apellidos")]
        [StringLength(50, ErrorMessage = "Introduzca un máximo de {1} caracteres")]
        public string Apellidos { get; set; }

        [StringLength(50)]
        [DisplayName("Cargo")]
        public string Cargo { get; set; }

        //[UIHint("EmailAddress")]
        [RegularExpression(@"[a-z0-9!#$%&'*+/=?^_`{|}~-]+(?:\.[a-z0-9!#$%&'*+/=?^_`{|}~-]+)*@(?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\.)+[a-z0-9](?:[a-z0-9-]*[a-z0-9])?", 
            ErrorMessage = "Formato inválido de {0}")]
        [DisplayName("Correo electrónico")]
        //[DataType(DataType.EmailAddress)]
        [StringLength(100, ErrorMessage = "Introduzca un máximo {0} caracteres")]
        public string Email { get; set; }

        //[UIHint("PhoneNumber")]
        [DisplayName("Teléfono")]
        [RegularExpression(@"\d+", ErrorMessage = "Formato inválido de {0}. Introduzca sólo numeros")]
        [StringLength(15, MinimumLength = 9, ErrorMessage = "Introduzca un número entre 9 y {1} caracteres")]
        public string Telefono { get; set; }

        [StringLength(50, ErrorMessage = "Introduzca un máximo {1} caracteres")]
        [DisplayName("Extension")]
        public string Extension { get; set; }
    }
}