﻿using System.ComponentModel;
using System.ComponentModel.DataAnnotations;
using GPAS.Validators;

namespace GPAS.Models
{
    /// <summary>   
    /// Se usa el atributo MetadataType para indicar en que clase se encuentran las anotaciones
    /// de la clase parcial Delegacion generada por el ORM (Entity Framework)
    /// </summary>
    [MetadataType(typeof (DelegacionMetadata))]
    public partial class Delegacion
    {
        /// <summary>   
        /// Propiedad que devuelve el nombre completo de la delegación de una organización
        /// </summary>
        public string NombreCompleto
        {
            get
            {
                if (Organizacion != null)
                    return Organizacion.Nombre + " - " + Nombre;
                else
                    return Nombre;
            }
        }
    }

    /// <summary>
    /// Se crea una clase 'buddy' como contenedor de anotaciones de la clase Delegacion
    /// </summary>
    public class DelegacionMetadata
    {
        [DisplayName("Id. delegación")]
        public int IdDelegacion { get; set; }

        [Required]
        [DisplayName("Organizacion")]
        public int IdOrganizacion { get; set; }

        [Required(ErrorMessage = "El {0} es obligatorio")]
        [DisplayName("Nombre")]
        [StringLength(50, ErrorMessage = "Introduzca un máximo de {1} caracteres")]
        public string Nombre { get; set; }

        [StringLength(100)]
        [DisplayName("Responsable")]
        public string Responsable { get; set; }

        [DisplayName("Teléfono")]
        [CustomValidators.PhoneNumberFormatAttribute("999999999",
            ErrorMessage = "Introduzca un número de teléfono válido")]
        public string Telefono { get; set; }

        [Required]
        [RegularExpression(@"[a-z0-9!#$%&'*+/=?^_`{|}~-]+(?:\.[a-z0-9!#$%&'*+/=?^_`{|}~-]+)*@(?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\.)+[a-z0-9](?:[a-z0-9-]*[a-z0-9])?", 
            ErrorMessage = "No es un formato de correo electrónico válido")]
        [DisplayName("Correo electrónico")]
        [DataType(DataType.EmailAddress)]
        [StringLength(100, ErrorMessage = "Introduzca un máximo de {1} caracteres")]
        public string EMail { get; set; }

        [StringLength(100, ErrorMessage = "Introduzca un máximo de {1} caracteres")]
        [DisplayName("Dirección")]
        public string Direccion { get; set; }

        [DisplayName("Población")]
        public int IdPoblacion { get; set; }
    }
}