﻿using System.ComponentModel;
using System.ComponentModel.DataAnnotations;
using System.Web.Mvc;

namespace GPAS.Models
{
    /// <summary>   
    /// Se usa el atributo MetadataType para indicar en que clase se encuentran las anotaciones
    /// de la clase parcial Entidad generada por el ORM (Entity Framework)
    /// </summary>
    [MetadataType(typeof (EntidadMetadata))]
    public partial class Entidad
    {
        /// <summary>   
        /// Propiedad que establece la dirección postal de una entidad
        /// </summary>
        public DireccionPostal DireccionPostal
        {
            get
            {
                return new DireccionPostal()
                           {
                               Direccion = this.Direccion,
                               CodigoPostal = this.CodigoPostal,
                               IdPoblacion = this.IdPoblacion 
                           };
            }
            set
            {
                this.Direccion = value.Direccion;
                this.CodigoPostal = value.CodigoPostal;
                this.IdPoblacion = value.IdPoblacion;
            }
        }

    }

    /// <summary>
    /// Se crea una clase 'buddy' como contenedor de anotaciones de la clase Contacto
    /// </summary>
    public class EntidadMetadata
    {
        [DisplayName("Id. entidad")]
        public int IdEntidad { get; set; }

        [DisplayName("Tipo entidad")]
        public int IdTipoEntidad { get; set; }

        [Required]
        [DisplayName("Nombre")]
        [StringLength(100, ErrorMessage = "Introduzca un máximo de {1} caracteres")]
        public string Nombre { get; set; }

        [RegularExpression(@"[a-z0-9!#$%&'*+/=?^_`{|}~-]+(?:\.[a-z0-9!#$%&'*+/=?^_`{|}~-]+)*@(?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\.)+[a-z0-9](?:[a-z0-9-]*[a-z0-9])?", 
            ErrorMessage = "No es un formato de correo electrónico válido")]
        [DisplayName("Correo electrónico")]
        [DataType(DataType.EmailAddress)]
        [StringLength(100, ErrorMessage = "Introduzca un máximo de {1} caracteres")]
        public string EMail { get; set; }

        [DisplayName("Página web")]
        [DataType(DataType.Url)]
        [StringLength(100, ErrorMessage = "Introduzca un máximo de {1} caracteres")]
        public string Web { get; set; }

        [DisplayName("Dirección")]
        [StringLength(100, ErrorMessage = "Introduzca un máximo de {1} caracteres")]
        public string Direccion { get; set; }

        [DisplayName("Código postal")]
        [StringLength(5, ErrorMessage = "Introduzca un máximo de {1} caracteres")]
        //[Range(1, 99999, ErrorMessage = "El {0} debe estar entre {1} y {2}")]
        public string CodigoPostal { get; set; }

        [DisplayName("Población")]
        public int IdPoblacion { get; set; }

        [DisplayName("Primer teléfono")]
        [RegularExpression(@"\d+", ErrorMessage = "Formato inválido de {0}. Introduzca sólo numeros")]
        [StringLength(15, MinimumLength = 9, ErrorMessage = "Introduzca un número entre {2} y {1} caracteres")]
        //[CustomValidators.PhoneNumberFormatAttribute("999999999", ErrorMessage = "Introduzca un número de teléfono válido")]       
            public string Telefono1 { get; set; }

        [DisplayName("Segundo teléfono")]
        [RegularExpression(@"\d+", ErrorMessage = "Formato inválido de {0}. Introduzca sólo numeros")]
        [StringLength(15, MinimumLength = 9, ErrorMessage = "Introduzca un número entre {2} y {1} caracteres")]
        //[CustomValidators.PhoneNumberFormatAttribute("999999999",ErrorMessage = "Introduzca un número de teléfono válido")]
            public string Telefono2 { get; set; }

        [DisplayName("Móvil")]
        [RegularExpression(@"\d+", ErrorMessage = "Formato inválido de {0}. Introduzca sólo numeros")]
        [StringLength(15, MinimumLength = 9, ErrorMessage = "Introduzca un número entre {2} y {1} caracteres")]
        //[CustomValidators.PhoneNumberFormatAttribute("999999999", ErrorMessage = "Introduzca un número de teléfono válido")]
            public string Movil { get; set; }

        [AllowHtml]
        [DisplayName("Observaciones")]
        [StringLength(5000, ErrorMessage = "Introduzca un máximo de {1} caracteres")]
        [DataType(DataType.MultilineText)]
        public string Observaciones { get; set; }
    }
}