﻿using System;
using System.ComponentModel;
using System.ComponentModel.DataAnnotations;
using System.Web.Mvc;

namespace GPAS.Models
{
    /// <summary>   
    /// Se usa el atributo MetadataType para indicar en que clase se encuentran las anotaciones
    /// de la clase parcial Evento generada por el ORM (Entity Framework)
    /// </summary>
    [MetadataType(typeof (EventoMetadata))]
    public partial class Evento
    {
        /// <summary>   
        /// Propiedad que devuelve el nombre completo de un evento mostrando la acción y la población
        /// </summary>
        public string NombreCompleto
        {
            get
            {
                if (Accion != null && Poblacion != null)
                    return Accion.NombreCompleto + " - " + Nombre + " - " + Poblacion.NombreCompleto;
                else
                    return Nombre;
            }
        }

        /// <summary>   
        /// Propiedad que devuelve la geolocalización de un evento (en formato de Google maps)
        /// </summary>
        public GoogleMarker ToGoogleMarker() 
        {
            return new GoogleMarker()
            {
                SiteName = this.Accion.NombreCompleto + " - " + this.Nombre,
                InfoWindow = this.Observaciones != null ? this.Observaciones : this.Nombre + " - " + 
                                    String.Format("{0:d}", this.FechaInicio) + " - " + 
                                    String.Format("{0:d}", this.FechaFin),
                Latitude = Convert.ToDouble(this.Poblacion.Latitud),
                Longitude = Convert.ToDouble(this.Poblacion.Longitud)
            };
        }
    }

    /// <summary>
    /// Se crea una clase 'buddy' como contenedor de anotaciones de la clase Evento
    /// </summary>
    public class EventoMetadata
    {
        [DisplayName("Id. evento")]
        public int IdEvento { get; set; }

        [Required(ErrorMessage = "La {0} es obligatoria")]
        [DisplayName("Acción")]
        public int IdAccion { get; set; }

        [Required(ErrorMessage = "El {0} es obligatorio")]
        [DisplayName("Nombre")]
        [StringLength(100, ErrorMessage = "Introduzca un máximo de {1} caracteres")]
        public string Nombre { get; set; }

        [Required(ErrorMessage = "La {0} es obligatoria")]
        //[Range(typeof (DateTime), "1/1/1900", "1/1/2099")]
        [DataType(DataType.Date, ErrorMessage = "La {0} ha de ser una fecha")]
        [DisplayName("Fecha de inicio")]
        public DateTime FechaInicio { get; set; }

        [Required(ErrorMessage = "La {0} es obligatoria")]
        //[Range(typeof (DateTime), "1/1/1900", "1/1/2099")]
        [DataType(DataType.Date, ErrorMessage = "La {0} ha de ser una fecha")]
        [DisplayName("Fecha de fin")]
        public DateTime FechaFin { get; set; }

        [StringLength(100, ErrorMessage = "Introduzca un máximo de {1} caracteres")]
        [DisplayName("Dirección")]
        public string Direccion { get; set; }

        [StringLength(5, ErrorMessage = "Introduzca un máximo de {1} caracteres")]
        //[Range(1, 99999, ErrorMessage = "El {0} debe estar entre {1} y {2}")]
        [DisplayName("Código postal")]
        public string CodigoPostal { get; set; }

        [DisplayName("Población")]
        public int IdPoblacion { get; set; }

        [AllowHtml]
        [DisplayName("Observaciones")]
        [StringLength(5000, ErrorMessage = "Introduzca un máximo de {1} caracteres")]
        [DataType(DataType.MultilineText)]
        public string Observaciones { get; set; }
    }
}