﻿using System;
using System.ComponentModel;
using System.ComponentModel.DataAnnotations;

namespace GPAS.Models
{
    /// <summary>   
    /// Se usa el atributo MetadataType para indicar en que clase se encuentran las anotaciones
    /// de la clase parcial Poblacion generada por el ORM (Entity Framework)
    /// </summary>
    [MetadataType(typeof (PoblacionMetadata))]
    public partial class Poblacion
    {
        /// <summary>   
        /// Propiedad que devuelve el nombre completo de una población
        /// </summary>
        public string NombreCompleto
        {
            get
            {
                if (Provincia != null)
                    return Provincia.Nombre + " - " + Nombre;
                else
                    return Nombre;
            }
        }
    }

    /// <summary>
    /// Se crea una clase 'buddy' como contenedor de anotaciones de la clase Poblacion
    /// </summary>
    public class PoblacionMetadata
    {
        [DisplayName("Id. población")]
        public int IdPoblacion { get; set; }

        [Required(ErrorMessage = "La {0} es obligatoria")]
        [DisplayName("Provincia")]
        public int IdProvincia { get; set; }

        [Required(ErrorMessage = "El {0} es obligatorio")]
        [StringLength(50), MaxLength]
        [DisplayName("Nombre")]
        public string Nombre { get; set; }

        [Required(ErrorMessage = "La {0} es obligatoria")]
        [StringLength(50), MaxLength]
        [DisplayName("Nombre seo")]
        public string PoblacionSeo { get; set; }

        [DisplayName("Código postal")]
        [StringLength(5, ErrorMessage = "Introduzca un máximo de {1} caracteres")]
        //[Range(1, 99999, ErrorMessage = "El {0} debe estar entre {1} y {2}")]
        public string CodigoPostal { get; set; }

        [Range(-90.0, 90.0, ErrorMessage = "La {0} ha de ser entre {1} y {2} grados")]
        [DisplayName("Latitud")]
        public Decimal Latitud { get; set; }

        [Range(-180.0, 180.0, ErrorMessage = "La {0} ha de ser entre {1} y {2} grados")]
        [DisplayName("Longitud")]
        public Decimal Longitud { get; set; }
    }
}