﻿using System.ComponentModel;
using System.ComponentModel.DataAnnotations;

namespace GPAS.Models
{
    /// <summary>   
    /// Se usa el atributo MetadataType para indicar en que clase se encuentran las anotaciones
    /// de la clase parcial Usuario generada por el ORM (Entity Framework)
    /// </summary>
    [MetadataType(typeof (UsuarioMetadata))]
    public partial class Usuario
    {
        /// <summary>   
        /// Propiedad que devuelve el nombre completo de un usuario
        /// </summary>
        public string NombreCompleto
        {
            get
            {
                if (Delegacion != null)
                    return Delegacion.NombreCompleto + " - " + Nombre + " " + Apellidos;
                else
                    return Nombre + " " + Apellidos;
            }
        }
    }

    /// <summary>
    /// Se crea una clase 'buddy' como contenedor de anotaciones de la clase Usuario
    /// </summary>
    public class UsuarioMetadata
    {
        [DisplayName("Id. usuario")]
        public int IdUsuario { get; set; }

        [Required(ErrorMessage = "La {0} es obligatoria")]
        [DisplayName("Delegación")]
        public int IdDelegacion { get; set; }

        [Required(ErrorMessage = "El {0} es obligatorio")]
        [DisplayName("Rol")]
        public int IdRol { get; set; }

        [Required(ErrorMessage = "El {0} es obligatorio")]
        [DisplayName("Nombre")]
        [StringLength(50, ErrorMessage = "Introduzca un máximo de {1} caracteres")]
        public string Nombre { get; set; }

        [Required(ErrorMessage = "Los {0} son obligatorios")]
        [DisplayName("Apellidos")]
        [StringLength(50, ErrorMessage = "Introduzca un máximo de {1} caracteres")]
        public string Apellidos { get; set; }

        //[UIHint("EmailAddress")]
        [RegularExpression(
            @"[a-z0-9!#$%&'*+/=?^_`{|}~-]+(?:\.[a-z0-9!#$%&'*+/=?^_`{|}~-]+)*@(?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\.)+[a-z0-9](?:[a-z0-9-]*[a-z0-9])?"
            , ErrorMessage = "Formato inválido de {0}")]
        [DisplayName("Correo electrónico")]
        //[DataType(DataType.EmailAddress)]
        [StringLength(100, ErrorMessage = "Introduzca un máximo {0} caracteres")]
        public string EMail { get; set; }

        //[UIHint("PhoneNumber")]
        [DisplayName("Primer teléfono")]
        [RegularExpression(@"\d+", ErrorMessage = "Formato inválido de {0}. Introduzca sólo numeros")]
        [StringLength(15, MinimumLength = 9, ErrorMessage = "Introduzca un número entre {2} y {1} caracteres")]
        //[CustomValidators.PhoneNumberFormat("999999999", ErrorMessage = "Introduzca un número de teléfono válido")]
            public string Telefono1 { get; set; }

        //[UIHint("PhoneNumber")]
        [DisplayName("Segundo teléfono")]
        [RegularExpression(@"\d+", ErrorMessage = "Formato inválido de {0}. Introduzca sólo numeros")]
        [StringLength(15, MinimumLength = 9, ErrorMessage = "Introduzca un número entre {2} y {1} caracteres")]
        //[CustomValidators.PhoneNumberFormat("999999999", ErrorMessage = "Introduzca un número de teléfono válido")]
            public string Telefono2 { get; set; }

        [Required(ErrorMessage = "El {0} es obligatorio")]
        [DisplayName("Nombre de usuario")]
        [StringLength(10, ErrorMessage = "El {0} no puede ser de mas de {1} caracteres")]
        //[Remote("ComprobarNombre", "Usuario", HttpMethod = "post", ErrorMessage = "El nombre de usuario no se puede duplicar")]
            public string NombreUsuario { get; set; }

        [Required(ErrorMessage = "La {0} es obligatoria")]
        [DisplayName("Contraseña")]
        [DataType(DataType.Password)]
        [StringLength(10, MinimumLength = 5, ErrorMessage = "Introduzca un número entre {2} y {1} caracteres")]
        public string Contrasena { get; set; }

        [DisplayName("Activo")]
        public bool Activo { get; set; }
    }
}